@@ -554,6 +554,10 @@ def sys_path_append_fp( fp ) :
     sys.path.append( os.path.dirname( fp ) )
     return(True)
 
+def file_stat( fp ) :
+    return( os.stat( fp ) )
+
+
 ################
 
 def thread_get_id( ) :
@@ -582,3 +586,25 @@ def math_dictkeylimit( d , k , l ) :
     elif ( int( d[ k ] ) > l ) :
         return( l )
     return(d[k])
+
+def dicts_merge( x , y ) :
+    z = x.copy( )
+    z.update( y )
+    return( z )
+
+def decode_redis(src):
+    if isinstance(src, list):
+        rv = list()
+        for key in src:
+            rv.append(decode_redis(key))
+        return rv
+    elif isinstance(src, dict):
+        rv = dict()
+        for key in src:
+            rv[key.decode()] = decode_redis(src[key])
+        return rv
+    elif isinstance(src, bytes):
+        return src.decode()
+    else:
+        raise Exception("type not handled: " +type(src))
+        
\ No newline at end of file
